import pickle
import shutil
from typing import Text

import requests


class Tts:
    def __init__(self, region: Text, text: Text, voice: Text):
        self.region = region
        self.text = text
        self.voice = voice

    def convert(self, file_name: Text):
        local_filename = file_name
        with requests.post("http://137.184.57.49:8000/convert", json={"region": self.region,
                                                                      "text": self.text, "voice": self.voice},
                           stream=True) as r:
            with open(local_filename, 'wb') as f:
                shutil.copyfileobj(r.raw, f)
        return local_filename

    def convert_nd_array(self):
        response = requests.post("http://137.184.57.49:8000/convert_nd_array", json={"region": self.region,
                                                                            "text": self.text, "voice": self.voice})
        return response.json()






#!/usr/bin/env python3
import pathlib

import setuptools
from ruth_tts import VERSION


here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

core_requirements = [

    "requests~=2.23.0",

]


setuptools.setup(
    name='ruth-TTS',
    description="PYTHON LIBRARY FOR RUTH-TTS",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="",
    author='puratalk',
    author_email='info@puretalk.ai',
    version=VERSION,
    install_requires=core_requirements,
    python_requires='>=3.7,<3.9',
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    include_package_data=True,
    package_data={
        "data": ["*.txt"]
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 3.8',
    ],
    entry_points={"console_scripts": ["ruth = ruth.cli.cli:entrypoint"]},
)